@@ -1,44 +1,32 @@
 import os
 
 import jinja2
+from illusionist.preprocessor import IllusionistPreprocessor
 from nbconvert.exporters.html import HTMLExporter
-from traitlets import default
 
-try:
-    from illusionist.preprocessor import IllusionistPreprocessor
-except ImportError:
-    IllusionistPreprocessor = False
-
-from .utils import DEV_MODE
+from jupyter_flex.config import settings
 
 
-@jinja2.contextfunction
+@jinja2.pass_context
 def include_external_file(ctx, name):
     """Include a file relative to the notebook"""
     with open(os.path.abspath(name), "r") as f:
         content = f.read()
-    return jinja2.Markup(content)
-
-
-preprocessors = []
-if IllusionistPreprocessor:
-    preprocessors.append(IllusionistPreprocessor)
+    return jinja2.utils.Markup(content)
 
 
 class FlexIllusionistExporter(HTMLExporter):
     # "File -> Download as" menu in the notebook
     export_from_notebook = "Flex Dashboard (Illusionist)"
+    extra_template_paths = [settings.templates_dir]
+    template_file = "nbconvert/flex/index.html.j2"
 
-    # Add illusionist (if installed)
-    preprocessors = preprocessors
-
-    @default("template_name")
-    def _template_name_default(self):
-        return "flex"
+    # Add illusionist
+    preprocessors = [IllusionistPreprocessor]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.environment.globals["dev_mode"] = DEV_MODE
+        self.environment.globals["dev_mode"] = settings.dev_mode
 
     def _init_resources(self, resources):
         resources = super()._init_resources(resources)
